# Basic 1 compartment PK model with 1st order absorption
# Estimation of lag time
# Additive-proportional residual error model
# No covariates
#
# Consideration of NONMEM, MONOLIX

rm(list=ls())
library(IQRtools)
IQRinitCompliance("example_2.R")

# Load structural model
model <- IQRmodel("example_2_model.txt")

# OPTION 1: Define dataset by path
data <- data_IQRest(
  datafile = "example_2_data.csv",
  covNames = c("WT0"),
  catNames = c("SEX"),
  regressorNames = NULL
)

# Define dosing
# If lag time desired to be estimated/fixed in the model
# then for each INPUTn with lag time the lag time parameter 
# name needs to be defined
dosing <- dosing_IQRest(
  INPUT1 = c(type="BOLUS",Tlag="Tlag1")
)

# Define model specification
modelSpec <- modelSpec_IQRest(
  POPvalues0      = c(ka=1,   CL=1,   Vc=10,   Tlag1=0.1),
  POPestimate     = c(ka=1,   CL=1,   Vc=1,    Tlag1=1),

  IIVdistribution = c(ka="L", CL="L", Vc="L",  Tlag1="L"),
  
  IIVvalues0      = c(ka=0.5, CL=0.5, Vc=0.5,  Tlag1=0.5),
  IIVestimate     = c(ka=1,   CL=1,   Vc=1,    Tlag1=1),
  
  errorModel = list(
    OUTPUT1 = c("absrel",1,0.3)
  )
)

# Generate estimation object (tool independent)
est <- IQRnlmeEst(model,dosing,data,modelSpec)

# Generate models in NONMEM, MONOLIX 
# (used version of NLMIXR does not support lag time with ODEs)

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_02_NONMEM",
  tool = "NONMEM",
  comment="NONMEM - lag time, addprop error, no covariates"
)

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_02_MONOLIX",
  tool = "MONOLIX",
  comment="MONOLIX - lag time, addprop error, no covariates"
)

# Run models
run_IQRnlmeProject("Models/MODEL_02_NONMEM")
run_IQRnlmeProject("Models/MODEL_02_MONOLIX")

