# Example on how to simulate using event table
rm(list=ls())
library(IQRtools)
library(ggplot2)

# Define model
project <- "Models/MODEL_02_MONOLIX"

# Load info
model <- getModel_IQRnlmeProject(project)
data <- getData_IQRnlmeProject(project)
param <- getIndivParameters_IQRnlmeProject(project)

# Merge data and parameters
dataparam <- dplyr::left_join(data,param,by=c("USUBJID","ID"))

# Generate event table
eventTable <- IQReventTable(
  dataparam,
  regression = c("ka","CL","Vc","Tlag1")
)
eventTable

# Simulate the model
res <- sim_IQRmodel(model = model,eventTable = eventTable,simtime=seq(0,48,0.1))

# Plot
IQRggplot(res,aes(x=TIME,y=Cc,group=ID)) + 
  geom_line()
