# Basic 1 compartment PK model with 0 order absorption into central compartment
# Estimation of lag time
# Estimation of 0-order absorption time
# Proportional residual error model
# No covariates
#
# Consideration of NONMEM, MONOLIX

rm(list=ls())
library(IQRtools)
IQRinitCompliance("example_3.R")

# Load structural model
model <- IQRmodel("example_3_model.txt")

# OPTION 1: Define dataset by path
data <- data_IQRest(
  datafile = "example_3_data.csv",
  covNames = c("WT0"),
  catNames = c("SEX"),
  regressorNames = NULL
)

# Define dosing
# In the case of 0-order absorption through a selected INPUTn,
# the name of the model parameter representing the absorption time 
# needs to be defined. The parameter has to be defined in the IQRmodel file.
dosing <- dosing_IQRest(
  INPUT1 = c(type="ABSORPTION0",Tlag="Tlag1",Tk0="Tk0")
)

# Define model specification
modelSpec <- modelSpec_IQRest(
  POPvalues0      = c(Tk0=1,   CL=1,   Vc=10,   Tlag1=0.1),
  POPestimate     = c(Tk0=1,   CL=1,   Vc=1,    Tlag1=1),

  IIVdistribution = c(Tk0="L", CL="L", Vc="L",  Tlag1="L"),
  
  IIVvalues0      = c(Tk0=0.5, CL=0.5, Vc=0.5,  Tlag1=0.5),
  IIVestimate     = c(Tk0=1,   CL=1,   Vc=1,    Tlag1=1),
  
  errorModel = list(
    OUTPUT1 = c("rel",0.3)
  )
)

# Generate estimation object (tool independent)
est <- IQRnlmeEst(model,dosing,data,modelSpec)

# Generate models in NONMEM, MONOLIX 
# (used version of NLMIXR does not support lag time with ODEs)

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_03_NONMEM",
  tool = "NONMEM",
  comment="NONMEM - 0-order absorption, lag time, prop error, no covariates"
)

IQRnlmeProject(
  est,
  projectPath = "Models/MODEL_03_MONOLIX",
  tool = "MONOLIX",
  comment="MONOLIX - 0-order absorption, lag time, prop error, no covariates"
)

# Run models
run_IQRnlmeProject("Models/MODEL_03_NONMEM")
run_IQRnlmeProject("Models/MODEL_03_MONOLIX")

