# Dual PK models with different inputs
# Totally constructed example with 6 INPUTs and 2 OUTPUTs
#
# Consideration of NONMEM only

# Many inputs - 2 outputs
library(IQRtools)
rm(list = ls())
IQRinitCompliance("example_8.R")

# Define structural model
model         <- IQRmodel("example_model_8.txt")

# Define dosing
# This is a purely constructed example ... have a look at the example_8_model.txt file. 
# There are 6 INPUTn definitions. There are two cases of more than one INPUTn on the same 
# compartment.
dosing        <- list(
  INPUT1 = c(type="BOLUS",Tlag="Tlag1"),
  INPUT2 = c(type="INFUSION"),
  INPUT3 = c(type="ABSORPTION0",Tk0="Tk0",Tlag="Tlag3"),
  INPUT4 = c(type="ABSORPTION0",Tk0="Tk02",Tlag="Tlag4"),
  INPUT5 = c(type="BOLUS",Tlag="Tlag5"),
  INPUT6 = c(type="INFUSION",Tlag="Tlag6")
)

# Define data
# Special handling since more than one INPUTn on same compartment:
#  - The standard dataset format can be used for MONOLIX. No special handling of dataset needed
#  - For NONMEM this is different. Instead of YTYPE we need to use a CMT column. For this 
#    reason the example dataset does not include YTYPE but CMT ...
#    Read more in the help of the IQRnlmeData function.
?IQRnlmeData

data          <- list(
  datafile       = "dataNLME_CMT.csv"
)

# Uncomment following lines ... this is to demonstrate that if the standard YTYPE 
# column is used in the dataset - then IQR Tools issues an error asking the user to
# switch to the CMT column approach.
# data          <- list(
#   datafile       = "dataNLME.csv"
# )

# Define model specification
modelSpec     <- list(
  
  POPvalues0 = c(CL = 1, Vc = 10, Q1 = 1, Vp1 = 10),
  
  errorModel = list(
    OUTPUT1 = c("absrel", c(abs0=1,rel0=0.3)),
    OUTPUT2 = c("absrel", c(abs0=1,rel0=0.3))
  )
)

# Create estimation object
est <- IQRnlmeEst(model = model, dosing = dosing, data = data, modelSpec = modelSpec)

# Generate NONMEM project
projNONMEM <- IQRnlmeProject(
  est,
  projectPath="Models/MODEL_08",
  tool="NONMEM",
  comment = "Many inputs - more than one input on same compartment - 2 outputs"
)

# Example dataset intentionally kept small ... so results won't be pretty ... 
# But goal is to show how it would be used.


